### INTENTION and  CONTEXT
My intention is to implement the Scenario "{scenario_name}" described in detail in the given feature file "{feature_file_name}". Focus on this scenario only. The other described scenarios are not to be considered.

{Further implementation specific context ...}

